from setuptools import setup

setup(
  name='pybegin',
  packages=['pybegin'],
  description='Lets get started',
  version='0.0.1',
  url='http://intel.com/someplace',
  author='Tsemach Mizrachi',
  author_email='tsemach.mizachi@intelc.om',  
  install_requires=[], 
  keywords=['pip','geospatail','begin'] 
)
